==> nextcloud-16.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/accessibility/l10n/de.js <==
OC.L10N.register(
    "accessibility",
    {
    "High contrast theme" : "Kontrastreiches Design",
    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Ein kontrastreiches Design, das die Navigation erleichtert. Die Bildqualität wird reduziert, aber die Klarheit wird verbessert.",
    "Dark theme" : "Dunkles Design",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Ein dunkles Design, das die Augen entspannt, indem es die allgemeine Lichtstärke und Helligkeit reduziert. Es befindet sich noch in der Entwicklung, also melde bitte alle Probleme, die Du findest.",
    "Dyslexia font" : "Legasthenie-Schriftart",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic ist eine freie Schriftart, die entwickelt wurde, um einige der häufigsten Lesefehler, die durch Legasthenie verursacht werden, zu reduzieren.",
    "Accessibility" : "Barrierefreiheit",
    "Accessibility options for nextcloud" : "Optionen für Barrierefreiheit in Nextcloud",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Bietet verschiedene Optionen für Barrierefreiheit, um die Nutzung von Nextcloud zu erleichtern.",
    "Web Content Accessibility Guidelines" : "Richtlinien für die Barrierefreiheit von Webinhalten",
    "our issue tracker" : "Unser Issue Tracker",
    "our design team" : "Unser Design-Team",
    "Enable" : "Aktiviere",
    "Dark theme (beta)" : "Dunkles Design (beta)",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia. The typeface was created by Abelardo Gonzalez, who released it through an open-source license." : "OpenDyslexic ist eine freie Schriftart, die entwickelt wurde, um einige der häufigsten Lesefehler, die durch Legasthenie verursacht werden, zu reduzieren. Die Schriftart wurde von Abelardo Gonzalez erstellt, die unter einer Quelloffenen Lizenz veröffentlicht wurde.",
    "Provides multiple accessibilities options to ease your use of nextcloud" : "Bietet verschiedene Optionen für Barrierefreiheit, um die Nutzung von Nextcloud zu erleichtern.",
    "Themes" : "Themen",
    "Fonts" : "Schriftarten",
    "enabled" : "aktiviert"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-17.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/accessibility/l10n/de.js <==
OC.L10N.register(
    "accessibility",
    {
    "Dark theme" : "Dunkles Design",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Ein dunkles Design, das die Augen entspannt, indem es die allgemeine Lichtstärke und Helligkeit reduziert. Es befindet sich noch in der Entwicklung, also melde bitte alle Probleme, die Du findest.",
    "High contrast mode" : "Kontrastreicher Modus",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Ein kontrastreicher Modus, der die Navigation erleichtert. Die Bildqualität wird reduziert, die Übersichtlichkeit jedoch erhöht.",
    "Dyslexia font" : "Legastheniker-Schriftart",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic ist eine freie Schriftart, die entwickelt wurde, um einige der häufigsten Lesefehler, die durch Legasthenie verursacht werden, zu reduzieren.",
    "Accessibility" : "Barrierefreiheit",
    "Accessibility options for nextcloud" : "Optionen für Barrierefreiheit in Nextcloud",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Bietet verschiedene Optionen für Barrierefreiheit, um die Nutzung von Nextcloud zu erleichtern.",
    "Web Content Accessibility Guidelines" : "Richtlinien für die Barrierefreiheit von Webinhalten",
    "our issue tracker" : "Unser Issue Tracker",
    "our design team" : "Unser Design-Team",
    "Enable" : "Aktiviere",
    "High contrast theme" : "Kontrastreiches Design",
    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Ein kontrastreiches Design, das die Navigation erleichtert. Die Bildqualität wird reduziert, aber die Klarheit wird verbessert.",
    "Dark theme (beta)" : "Dunkles Design (beta)",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia. The typeface was created by Abelardo Gonzalez, who released it through an open-source license." : "OpenDyslexic ist eine freie Schriftart, die entwickelt wurde, um einige der häufigsten Lesefehler, die durch Legasthenie verursacht werden, zu reduzieren. Die Schriftart wurde von Abelardo Gonzalez erstellt, die unter einer Quelloffenen Lizenz veröffentlicht wurde.",
    "Provides multiple accessibilities options to ease your use of nextcloud" : "Bietet verschiedene Optionen für Barrierefreiheit, um die Nutzung von Nextcloud zu erleichtern.",
    "Themes" : "Themen",
    "Fonts" : "Schriftarten",
    "enabled" : "aktiviert"
},
"nplurals=2; plural=(n != 1);");
